@@ -511,8 +511,8 @@ ev_annotation_get_modified (EvAnnotation *annot)
  * @modified: string with the last modification date.
  *
  * Set the last modification date of @annot to @modified. To
- * set the last modification date using a #GTime, use
- * ev_annotation_set_modified_from_time() instead. You can monitor
+ * set the last modification date using a #time_t, use
+ * ev_annotation_set_modified_from_time_t() instead. You can monitor
  * changes to the last modification date by connecting to the
  * notify::modified signal on @annot.
  *
@@ -547,7 +547,11 @@ ev_annotation_set_modified (EvAnnotation *annot,
  * For the time-format used, see ev_document_misc_format_date().
  *
  * Returns: %TRUE if the last modified date has been updated, %FALSE otherwise.
+ *
+ * Deprecated: 3.42: use ev_annotation_set_modified_from_time_t instead as GTime is
+ *                   deprecated because it is not year-2038 safe
  */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 gboolean
 ev_annotation_set_modified_from_time (EvAnnotation *annot,
 				      GTime         utime)
@@ -571,6 +575,44 @@ ev_annotation_set_modified_from_time (EvAnnotation *annot,
 
 	return TRUE;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
+
+/**
+ * ev_annotation_set_modified_from_time_t:
+ * @annot: an #EvAnnotation
+ * @utime: a #time_t
+ *
+ * Set the last modification date of @annot to @utime.  You can
+ * monitor changes to the last modification date by connecting to the
+ * notify::modified sinal on @annot.
+ * For the time-format used, see ev_document_misc_format_datetime().
+ *
+ * Returns: %TRUE if the last modified date has been updated, %FALSE otherwise.
+ */
+gboolean
+ev_annotation_set_modified_from_time_t (EvAnnotation *annot,
+				        time_t        utime)
+{
+	gchar *modified;
+	g_autoptr (GDateTime) dt = g_date_time_new_from_unix_utc ((gint64)utime);
+
+	g_return_val_if_fail (EV_IS_ANNOTATION (annot), FALSE);
+
+	modified = ev_document_misc_format_datetime (dt);
+
+	if (g_strcmp0 (annot->modified, modified) == 0) {
+		g_free (modified);
+		return FALSE;
+	}
+
+	if (annot->modified)
+		g_free (annot->modified);
+
+	annot->modified = modified;
+	g_object_notify (G_OBJECT (annot), "modified");
+
+	return TRUE;
+}
 
 /**
  * ev_annotation_get_color:
