@@ -15,20 +15,18 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  $Id$
  */
 
+#pragma once
+
 #if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
 #error "Only <evince-document.h> can be included directly."
 #endif
 
-#ifndef EV_DOCUMENT_FIND_H
-#define EV_DOCUMENT_FIND_H
-
 #include <glib-object.h>
 #include <glib.h>
 
+#include "ev-macros.h"
 #include "ev-document.h"
 
 G_BEGIN_DECLS
@@ -65,17 +63,19 @@ struct _EvDocumentFindInterface
 	EvFindOptions (*get_supported_options)   (EvDocumentFind *document_find);
 };
 
+EV_PUBLIC
 GType         ev_document_find_get_type               (void) G_GNUC_CONST;
+EV_PUBLIC
 GList        *ev_document_find_find_text              (EvDocumentFind *document_find,
 						       EvPage         *page,
 						       const gchar    *text,
 						       gboolean        case_sensitive);
+EV_PUBLIC
 GList        *ev_document_find_find_text_with_options (EvDocumentFind *document_find,
 						       EvPage         *page,
 						       const gchar    *text,
 						       EvFindOptions   options);
+EV_PUBLIC
 EvFindOptions ev_document_find_get_supported_options  (EvDocumentFind *document_find);
 
 G_END_DECLS
-
-#endif /* EV_DOCUMENT_FIND_H */
