@@ -116,11 +116,6 @@ static void ev_view_presentation_set_cursor_for_location (EvViewPresentation *pv
 
 G_DEFINE_TYPE (EvViewPresentation, ev_view_presentation, GTK_TYPE_WIDGET)
 
-#if !GTK_CHECK_VERSION(3, 20, 0)
-static GdkRGBA black = { 0., 0., 0., 1. };
-static GdkRGBA white = { 1., 1., 1., 1. };
-#endif
-
 static void
 ev_view_presentation_set_normal (EvViewPresentation *pview)
 {
@@ -130,12 +125,8 @@ ev_view_presentation_set_normal (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_NORMAL;
-#if GTK_CHECK_VERSION(3, 20, 0)
 	gtk_style_context_remove_class (gtk_widget_get_style_context (widget),
 					"white-mode");
-#else
-        gdk_window_set_background_rgba (gtk_widget_get_window (widget), &black);
-#endif
         gtk_widget_queue_draw (widget);
 }
 
@@ -148,12 +139,8 @@ ev_view_presentation_set_black (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_BLACK;
-#if GTK_CHECK_VERSION(3, 20, 0)
 	gtk_style_context_remove_class (gtk_widget_get_style_context (widget),
 					"white-mode");
-#else
-        gdk_window_set_background_rgba (gtk_widget_get_window (widget), &black);
-#endif
         gtk_widget_queue_draw (widget);
 }
 
@@ -166,13 +153,8 @@ ev_view_presentation_set_white (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_WHITE;
-#if GTK_CHECK_VERSION(3, 20, 0)
 	gtk_style_context_add_class (gtk_widget_get_style_context (widget),
 				     "white-mode");
-#else
-        gdk_window_set_background_rgba (gtk_widget_get_window (widget), &white);
-        gtk_widget_queue_draw (widget);
-#endif
 }
 
 static void
@@ -236,6 +218,7 @@ ev_view_presentation_get_page_area (EvViewPresentation *pview,
 static gboolean
 transition_next_page (EvViewPresentation *pview)
 {
+	pview->trans_timeout_id = 0;
 	ev_view_presentation_next_page (pview);
 
 	return FALSE;
@@ -869,8 +852,8 @@ ev_view_presentation_get_link_at_location (EvViewPresentation *pview,
 }
 
 static void
-ev_vew_presentation_handle_link (EvViewPresentation *pview,
-                                 EvLink             *link)
+ev_view_presentation_handle_link (EvViewPresentation *pview,
+                                  EvLink             *link)
 {
 	EvLinkAction *action;
 
@@ -1077,7 +1060,6 @@ ev_view_presentation_draw (GtkWidget *widget,
 	GdkRectangle        overlap;
 	cairo_surface_t    *surface;
         GdkRectangle        clip_rect;
-#if GTK_CHECK_VERSION(3, 20, 0)
 	GtkStyleContext    *context;
 
 	context = gtk_widget_get_style_context (GTK_WIDGET (pview));
@@ -1085,7 +1067,6 @@ ev_view_presentation_draw (GtkWidget *widget,
                                0, 0,
                                gtk_widget_get_allocated_width (widget),
                                gtk_widget_get_allocated_height (widget));
-#endif
 
         if (!gdk_cairo_get_clip_rectangle (cr, &clip_rect))
                 return FALSE;
@@ -1238,7 +1219,7 @@ ev_view_presentation_button_release_event (GtkWidget      *widget,
 								  event->x,
 								  event->y);
 		if (link)
-			ev_vew_presentation_handle_link (pview, link);
+			ev_view_presentation_handle_link (pview, link);
 		else
 			ev_view_presentation_next_page (pview);
 	}
@@ -1521,9 +1502,7 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 	widget_class->motion_notify_event = ev_view_presentation_motion_notify_event;
 	widget_class->scroll_event = ev_view_presentation_scroll_event;
 
-#if GTK_CHECK_VERSION(3, 20, 0)
 	gtk_widget_class_set_css_name (widget_class, "evpresentationview");
-#endif
 
 	gobject_class->constructor = ev_view_presentation_constructor;
 	gobject_class->set_property = ev_view_presentation_set_property;
@@ -1628,37 +1607,11 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 				      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_PAGE_BACKWARD);
 }
 
-#if !GTK_CHECK_VERSION(3, 20, 0)
-static void
-ev_view_presentation_init_css(void)
-{
-        static gsize initialization_value = 0;
-
-        if (g_once_init_enter (&initialization_value)) {
-                GtkCssProvider *provider;
-
-                provider = gtk_css_provider_new ();
-                gtk_css_provider_load_from_data (provider,
-                                                 "EvViewPresentation {\n"
-                                                 " background-color: black; }",
-                                                 -1, NULL);
-                gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                           GTK_STYLE_PROVIDER (provider),
-                                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-                g_object_unref (provider);
-                g_once_init_leave (&initialization_value, 1);
-        }
-}
-#endif
-
 static void
 ev_view_presentation_init (EvViewPresentation *pview)
 {
 	gtk_widget_set_can_focus (GTK_WIDGET (pview), TRUE);
         pview->is_constructing = TRUE;
-#if !GTK_CHECK_VERSION(3, 20, 0)
-        ev_view_presentation_init_css();
-#endif
 }
 
 GtkWidget *
