@@ -18,13 +18,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#pragma once
+
 #if !defined (EVINCE_COMPILATION)
 #error "This is a private header."
 #endif
 
-#ifndef __EV_VIEW_PRIVATE_H__
-#define __EV_VIEW_PRIVATE_H__
-
 #include "ev-view.h"
 #include "ev-document-model.h"
 #include "ev-pixbuf-cache.h"
@@ -294,6 +293,7 @@ struct _EvViewClass {
 				       EvSourceLink   *link);
         void     (*annot_added)       (EvView         *view,
 				       EvAnnotation   *annot);
+        void     (*annot_cancel_add)  (EvView         *view);
         void     (*annot_changed)     (EvView         *view,
 				       EvAnnotation   *annot);
         void     (*annot_removed)     (EvView         *view,
@@ -355,6 +355,3 @@ void _ev_view_focus_form_field    (EvView      *view,
 
 void _ev_view_ensure_rectangle_is_visible (EvView       *view,
 					   GdkRectangle *rect);
-
-#endif  /* __EV_VIEW_PRIVATE_H__ */
-
